@@ -1,7 +1,7 @@
 package Perinci::Sub::GetArgs::Argv;
 
-our $DATE = '2016-12-15'; # DATE
-our $VERSION = '0.80'; # VERSION
+our $DATE = '2017-04-19'; # DATE
+our $VERSION = '0.81'; # VERSION
 
 use 5.010001;
 use strict;
@@ -1113,7 +1113,7 @@ Perinci::Sub::GetArgs::Argv - Get subroutine arguments from command line argumen
 
 =head1 VERSION
 
-This document describes version 0.80 of Perinci::Sub::GetArgs::Argv (from Perl distribution Perinci-Sub-GetArgs-Argv), released on 2016-12-15.
+This document describes version 0.81 of Perinci::Sub::GetArgs::Argv (from Perl distribution Perinci-Sub-GetArgs-Argv), released on 2017-04-19.
 
 =head1 SYNOPSIS
 
@@ -1131,7 +1131,11 @@ processed, see Perinci::CmdLine's documentation.
 =head1 FUNCTIONS
 
 
-=head2 gen_getopt_long_spec_from_meta(%args) -> [status, msg, result, meta]
+=head2 gen_getopt_long_spec_from_meta
+
+Usage:
+
+ gen_getopt_long_spec_from_meta(%args) -> [status, msg, result, meta]
 
 Generate Getopt::Long spec from Rinci function metadata.
 
@@ -1256,7 +1260,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 get_args_from_argv(%args) -> [status, msg, result, meta]
+=head2 get_args_from_argv
+
+Usage:
+
+ get_args_from_argv(%args) -> [status, msg, result, meta]
 
 Get subroutine arguments (%args) from command-line arguments (@ARGV).
 
@@ -1421,7 +1429,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Su
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-Sub-GetArgs-Argv>.
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-Sub-GetArgs-Argv>.
 
 =head1 BUGS
 
@@ -1441,7 +1449,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
